import { APIGatewayProxyEventV2, APIGatewayProxyEvent, ALBEvent, APIGatewayProxyHandlerV2, APIGatewayProxyHandler, ALBHandler } from 'aws-lambda';
import { AppLoadContext, ServerBuild } from '@remix-run/node';

declare enum AWSProxy {
    APIGatewayV1 = "APIGatewayV1",
    APIGatewayV2 = "APIGatewayV2",
    ALB = "ALB"
}
/**
 * A function that returns the value to use as `context` in route `loader` and
 * `action` functions.
 *
 * You can think of this as an escape hatch that allows you to pass
 * environment/platform-specific values through to your loader/action.
 */
declare type GetLoadContextFunction = (event: APIGatewayProxyEventV2 | APIGatewayProxyEvent | ALBEvent) => AppLoadContext;
declare type RequestHandler = APIGatewayProxyHandlerV2 | APIGatewayProxyHandler | ALBHandler;
/**
 * Returns a request handler for Architect that serves the response using
 * Remix.
 */
declare function createRequestHandler({ build, getLoadContext, mode, awsProxy }: {
    build: ServerBuild;
    getLoadContext?: GetLoadContextFunction;
    mode?: string;
    awsProxy?: AWSProxy;
}): RequestHandler;

export { AWSProxy, GetLoadContextFunction, RequestHandler, createRequestHandler };
