"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  AWSProxy: () => AWSProxy,
  createRequestHandler: () => createRequestHandler
});
module.exports = __toCommonJS(src_exports);

// src/server.ts
var import_node4 = require("@remix-run/node");

// src/adapters/api-gateway-v1.ts
var import_node = require("@remix-run/node");
var import_url = require("url");

// src/binaryTypes.ts
var binaryTypes = [
  "application/octet-stream",
  "application/epub+zip",
  "application/msword",
  "application/pdf",
  "application/rtf",
  "application/vnd.amazon.ebook",
  "application/vnd.ms-excel",
  "application/vnd.ms-powerpoint",
  "application/vnd.openxmlformats-officedocument.presentationml.presentation",
  "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",
  "application/vnd.openxmlformats-officedocument.wordprocessingml.document",
  "font/otf",
  "font/woff",
  "font/woff2",
  "image/bmp",
  "image/gif",
  "image/jpeg",
  "image/png",
  "image/tiff",
  "image/vnd.microsoft.icon",
  "image/webp",
  "audio/3gpp",
  "audio/aac",
  "audio/basic",
  "audio/mpeg",
  "audio/ogg",
  "audio/wavaudio/webm",
  "audio/x-aiff",
  "audio/x-midi",
  "audio/x-wav",
  "video/3gpp",
  "video/mp2t",
  "video/mpeg",
  "video/ogg",
  "video/quicktime",
  "video/webm",
  "video/x-msvideo",
  "application/java-archive",
  "application/vnd.apple.installer+xml",
  "application/x-7z-compressed",
  "application/x-apple-diskimage",
  "application/x-bzip",
  "application/x-bzip2",
  "application/x-gzip",
  "application/x-java-archive",
  "application/x-rar-compressed",
  "application/x-tar",
  "application/x-zip",
  "application/zip"
];
function isBinaryType(contentType) {
  if (!contentType)
    return false;
  return binaryTypes.some((t) => contentType.includes(t));
}

// src/adapters/api-gateway-v1.ts
function createRemixRequest(event) {
  const host = event.headers["x-forwarded-host"] || event.headers.Host;
  const scheme = event.headers["x-forwarded-proto"] || "http";
  const rawQueryString = new import_url.URLSearchParams(event.queryStringParameters).toString();
  const search = rawQueryString.length > 0 ? `?${rawQueryString}` : "";
  const url = new URL(event.path + search, `${scheme}://${host}`);
  const isFormData = event.headers["content-type"]?.includes("multipart/form-data");
  return new Request(url.href, {
    method: event.requestContext.httpMethod,
    headers: createRemixHeaders(event.headers),
    body: event.body && event.isBase64Encoded ? isFormData ? Buffer.from(event.body, "base64") : Buffer.from(event.body, "base64").toString() : event.body || void 0
  });
}
function createRemixHeaders(requestHeaders) {
  const headers = new Headers();
  for (const [header, value] of Object.entries(requestHeaders)) {
    if (value) {
      headers.append(header, value);
    }
  }
  return headers;
}
async function sendRemixResponse(nodeResponse) {
  const contentType = nodeResponse.headers.get("Content-Type");
  const isBase64Encoded = isBinaryType(contentType);
  let body;
  if (nodeResponse.body) {
    if (isBase64Encoded) {
      body = await (0, import_node.readableStreamToString)(nodeResponse.body, "base64");
    } else {
      body = await nodeResponse.text();
    }
  }
  return {
    statusCode: nodeResponse.status,
    headers: Object.fromEntries(nodeResponse.headers.entries()),
    body: body || "",
    isBase64Encoded
  };
}
var apiGatewayV1Adapter = {
  createRemixRequest,
  sendRemixResponse
};

// src/adapters/api-gateway-v2.ts
var import_node2 = require("@remix-run/node");
function createRemixRequest2(event) {
  const host = event.headers["x-forwarded-host"] || event.headers.host;
  const search = event.rawQueryString.length ? `?${event.rawQueryString}` : "";
  const scheme = event.headers["x-forwarded-proto"] || "http";
  const url = new URL(event.rawPath + search, `${scheme}://${host}`);
  const isFormData = event.headers["content-type"]?.includes("multipart/form-data");
  return new Request(url.href, {
    method: event.requestContext.http.method,
    headers: createRemixHeaders2(event.headers, event.cookies),
    body: event.body && event.isBase64Encoded ? isFormData ? Buffer.from(event.body, "base64") : Buffer.from(event.body, "base64").toString() : event.body
  });
}
function createRemixHeaders2(requestHeaders, requestCookies) {
  const headers = new Headers();
  for (const [header, value] of Object.entries(requestHeaders)) {
    if (value) {
      headers.append(header, value);
    }
  }
  if (requestCookies) {
    headers.append("Cookie", requestCookies.join("; "));
  }
  return headers;
}
async function sendRemixResponse2(nodeResponse) {
  const cookies = [];
  for (const [key, values] of Object.entries(nodeResponse.headers.raw())) {
    if (key.toLowerCase() === "set-cookie") {
      for (const value of values) {
        cookies.push(value);
      }
    }
  }
  if (cookies.length) {
    nodeResponse.headers.delete("Set-Cookie");
  }
  const contentType = nodeResponse.headers.get("Content-Type");
  const isBase64Encoded = isBinaryType(contentType);
  let body;
  if (nodeResponse.body) {
    if (isBase64Encoded) {
      body = await (0, import_node2.readableStreamToString)(nodeResponse.body, "base64");
    } else {
      body = await nodeResponse.text();
    }
  }
  return {
    statusCode: nodeResponse.status,
    headers: Object.fromEntries(nodeResponse.headers.entries()),
    cookies,
    body,
    isBase64Encoded
  };
}
var apiGatewayV2Adapter = {
  createRemixRequest: createRemixRequest2,
  sendRemixResponse: sendRemixResponse2
};

// src/adapters/application-load-balancer.ts
var import_node3 = require("@remix-run/node");
var import_url2 = require("url");
function createRemixRequest3(event) {
  const headers = event?.headers || {};
  const host = headers["x-forwarded-host"] || headers.Host;
  const scheme = headers["x-forwarded-proto"] || "http";
  const rawQueryString = new import_url2.URLSearchParams(event.queryStringParameters).toString();
  const search = rawQueryString.length > 0 ? `?${rawQueryString}` : "";
  const url = new URL(event.path + search, `${scheme}://${host}`);
  const isFormData = headers["content-type"]?.includes("multipart/form-data");
  return new Request(url.href, {
    method: event.httpMethod,
    headers: createRemixHeaders3(headers),
    body: event.body && event.isBase64Encoded ? isFormData ? Buffer.from(event.body, "base64") : Buffer.from(event.body, "base64").toString() : event.body || void 0
  });
}
function createRemixHeaders3(requestHeaders) {
  const headers = new Headers();
  for (const [header, value] of Object.entries(requestHeaders)) {
    if (value) {
      headers.append(header, value);
    }
  }
  return headers;
}
async function sendRemixResponse3(nodeResponse) {
  const contentType = nodeResponse.headers.get("Content-Type");
  const isBase64Encoded = isBinaryType(contentType);
  let body;
  if (nodeResponse.body) {
    if (isBase64Encoded) {
      body = await (0, import_node3.readableStreamToString)(nodeResponse.body, "base64");
    } else {
      body = await nodeResponse.text();
    }
  }
  return {
    statusCode: nodeResponse.status,
    headers: Object.fromEntries(nodeResponse.headers.entries()),
    body: body || "",
    isBase64Encoded
  };
}
var applicationLoadBalancerAdapter = {
  createRemixRequest: createRemixRequest3,
  sendRemixResponse: sendRemixResponse3
};

// src/adapters/index.ts
var createRemixAdapter = (awsProxy) => {
  switch (awsProxy) {
    case "APIGatewayV1" /* APIGatewayV1 */:
      return apiGatewayV1Adapter;
    case "APIGatewayV2" /* APIGatewayV2 */:
      return apiGatewayV2Adapter;
    case "ALB" /* ALB */:
      return applicationLoadBalancerAdapter;
  }
};

// src/server.ts
var AWSProxy = /* @__PURE__ */ ((AWSProxy2) => {
  AWSProxy2["APIGatewayV1"] = "APIGatewayV1";
  AWSProxy2["APIGatewayV2"] = "APIGatewayV2";
  AWSProxy2["ALB"] = "ALB";
  return AWSProxy2;
})(AWSProxy || {});
function createRequestHandler({
  build,
  getLoadContext,
  mode = process.env.NODE_ENV,
  awsProxy = "APIGatewayV2" /* APIGatewayV2 */
}) {
  const handleRequest = (0, import_node4.createRequestHandler)(build, mode);
  return async (event) => {
    const awsAdapter = createRemixAdapter(awsProxy);
    const request = awsAdapter.createRemixRequest(event);
    const loadContext = getLoadContext?.(event);
    const response = await handleRequest(request, loadContext);
    return awsAdapter.sendRemixResponse(response);
  };
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  AWSProxy,
  createRequestHandler
});
//# sourceMappingURL=index.js.map